Module: DeliveryFivePostClient::Internal::Type::Union Private
- Includes:
- Converter, Util::SorbetRuntimeSupport
- Defined in:
- lib/delivery_five_post_client/internal/type/union.rb
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Instance Method Summary collapse
- #==(other) ⇒ Boolean
- #===(other) ⇒ Boolean
-
#coerce(value, state:) ⇒ Object
private
Tries to efficiently coerce the given value to one of the known variants.
- #dump(value, state:) ⇒ Object private
- #hash ⇒ Integer
- #inspect(depth: 0) ⇒ String private
- #to_sorbet_type ⇒ Object private
-
#variants ⇒ Array<Object>
private
All of the specified variants for this union.
Methods included from Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, to_sorbet_type
Methods included from Converter
coerce, dump, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#==(other) ⇒ Boolean
109 110 111 112 113 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 109 def ==(other) # rubocop:disable Layout/LineLength DeliveryFivePostClient::Internal::Type::Union === other && other.derefed_variants == derefed_variants # rubocop:enable Layout/LineLength end |
#===(other) ⇒ Boolean
98 99 100 101 102 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 98 def ===(other) known_variants.any? do |_, variant_fn| variant_fn.call === other end end |
#coerce(value, state:) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Tries to efficiently coerce the given value to one of the known variants.
If the value cannot match any of the known variants, the coercion is considered non-viable and returns the original value.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 142 def coerce(value, state:) if (target = resolve_variant(value)) return DeliveryFivePostClient::Internal::Type::Converter.coerce(target, value, state: state) end strictness = state.fetch(:strictness) exactness = state.fetch(:exactness) alternatives = [] known_variants.each do |_, variant_fn| target = variant_fn.call exact = state[:exactness] = {yes: 0, no: 0, maybe: 0} state[:branched] += 1 coerced = DeliveryFivePostClient::Internal::Type::Converter.coerce(target, value, state: state) yes, no, maybe = exact.values if (no + maybe).zero? || (!strictness && yes.positive?) exact.each { exactness[_1] += _2 } state[:exactness] = exactness return coerced elsif maybe.positive? alternatives << [[-yes, -maybe, no], exact, coerced] end end case alternatives.sort_by!(&:first) in [] exactness[:no] += 1 state[:error] = ArgumentError.new("no matching variant for #{value.inspect}") value in [[_, exact, coerced], *] exact.each { exactness[_1] += _2 } coerced end .tap { state[:exactness] = exactness } ensure state[:strictness] = strictness end |
#dump(value, state:) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 190 def dump(value, state:) if (target = resolve_variant(value)) return DeliveryFivePostClient::Internal::Type::Converter.dump(target, value, state: state) end known_variants.each do target = _2.call if target === value return DeliveryFivePostClient::Internal::Type::Converter.dump( target, value, state: state ) end end super end |
#hash ⇒ Integer
118 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 118 def hash = variants.hash |
#inspect(depth: 0) ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
234 235 236 237 238 239 240 241 242 243 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 234 def inspect(depth: 0) if depth.positive? return is_a?(Module) ? super() : self.class.name end members = variants.map { DeliveryFivePostClient::Internal::Type::Converter.inspect(_1, depth: depth.succ) } prefix = is_a?(Module) ? name : self.class.name "#{prefix}[#{members.join(' | ')}]" end |
#to_sorbet_type ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 212 def to_sorbet_type types = variants.map do DeliveryFivePostClient::Internal::Util::SorbetRuntimeSupport.to_sorbet_type(_1) end.uniq case types in [] T.noreturn in [type] type else T.any(*types) end end |
#variants ⇒ Array<Object>
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
All of the specified variants for this union.
28 |
# File 'lib/delivery_five_post_client/internal/type/union.rb', line 28 def variants = derefed_variants.map { _2 } |